@@ -1,6 +1,7 @@
 from ._base import Client
 
 from .lite import LiteserverClient
+from .quicknode import QuicknodeClient
 from .tonapi import TonapiClient
 from .toncenter import ToncenterClient
 
@@ -8,6 +9,7 @@ __all__ = [
     "Client",
 
     "LiteserverClient",
+    "QuicknodeClient",
     "TonapiClient",
     "ToncenterClient",
 ]
